Skip to contents

This function calculates mean relative condition calculated from the NEFSC bottom trawl survey Methods derived from Laurel Smith (https://github.com/Laurels1/Condition/blob/master/R/RelConditionEPU.R)

Usage

create_condition(
  input_path_condition,
  input_path_lw_coeffs,
  input_path_species
)

Arguments

input_path_condition

Character string. Full path to the condition data pull rds file.

input_path_lw_coeffs

Character string. Full path to the LWparams csv file in 'EDAB_Resources/workflow_resources/soe_workflows'.

input_path_species

Character string. Full path to the species.codes csv file in 'EDAB_Resources/workflow_resources/soe_workflows'.

Value

condition, ecodata::condition data frame

Examples

if (FALSE) { # \dontrun{
#create the ecodata::condition indicator
create_condition(
 input_path_lw_coeffs = "path/to/LWparams.csv",
 input_path_species = "path/to/species.codes.csv")

} # }