This function calculates mean relative condition calculated from the NEFSC bottom trawl survey Methods derived from Laurel Smith (https://github.com/Laurels1/Condition/blob/master/R/RelConditionEPU.R)
Arguments
- inputPath
Character string. Full path to the condition data pull rds file.
- inputPathLW
Character string. Full path to the LWparams csv file in 'EDAB_Resources/workflow_resources/soe_workflows'.
- inputPathSpecies
Character string. Full path to the species.codes csv file in 'EDAB_Resources/workflow_resources/soe_workflows'.