Function to process Massachusetts inshore bottom trawl survey for automated workflow
Source:R/mass_inshore_survey.R
create_mass_inshore_survey.RdData include aggregated time series of inshore fishery-independent trawl survey data from Massachusetts waters. MA inshore surveys have been performed biannually in the spring and fall since 1978.
Examples
if (FALSE) { # \dontrun{
# create the ecodata::mass_inshore_survey indicator
create_mass_inshore_survey(inputPathMassSurvey <- here::here("mass_inshore.rds"),
inputPathSpecies <- "/home/<user>/EDAB_Datasets/SOE_species_list_24.rds")
} # }