Calculates survey_shannon diversity index for automated workflow
Source:R/survey_shannon.R
create_survey_shannon.RdThis uses the survdat data pull from the survey package. It is formatted exactly like the ecodata data object This calculates the shannon diversity at the station level (by year, cruise etc) Then takes the mean of the shannon indices for each year
Examples
if (FALSE) { # \dontrun{
# create the ecodata::survey_shannon indicator
create_aggregate_biomass(inputPathAlbatros = "path/to/albatross.rds",
inputPathBigelow = "path/to/bigelow.rds")
} # }